.. tocolib documentation master file, created by
   sphinx-quickstart on Sat Sep  5 11:34:58 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../DESCRIPTION.rst

Contents
>>>>>>>>

.. toctree::
   :maxdepth: 3

   tocoli


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

